OC.L10N.register(
    "lib",
    {
    "Help" : "Pomoć",
    "Personal" : "Osobno",
    "Users" : "Korisnici",
    "Admin" : "Admin",
    "Recommended" : "Preporučljivo",
    "Unknown filetype" : "Nepoznat tip datoteke",
    "Invalid image" : "Nevažeća datoteka",
    "Authentication error" : "Grešna autentifikacije",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s na ovoj platformi neće raditi kako treba. Korištenje na vlastiti rizik!",
    "For the best results, please consider using a GNU/Linux server instead." : "Umjesto toga, za najbolje rezultate, molimo razmislite o mogućnosti korištenje GNU/Linux servera.",
    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
    "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemorisanja kao što je Zend OPcache ili eAccelerator."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
